"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RunnerSelfService = void 0;
const request_1 = require("../core/request");
class RunnerSelfService {
    /**
     * Get
     * Lists all information about yourself. <br> Please provide your runner jwt(that code we gave you during registration) for auth. <br> If you lost your jwt/personalized link please use the forgot endpoint.
     * @param jwt
     * @returns ResponseSelfServiceRunner
     * @throws ApiError
     */
    static async runnerSelfServiceControllerGet(jwt) {
        const result = await (0, request_1.request)({
            method: 'GET',
            path: `/api/runners/me/${jwt}`,
        });
        return result.body;
    }
    /**
     * Remove
     * Deletes all information about yourself. <br> Please provide your runner jwt(that code we gave you during registration) for auth. <br> If you lost your jwt/personalized link please use the forgot endpoint.
     * @param jwt
     * @param force
     * @returns ResponseSelfServiceRunner
     * @throws ApiError
     */
    static async runnerSelfServiceControllerRemove(jwt, force) {
        const result = await (0, request_1.request)({
            method: 'DELETE',
            path: `/api/runners/me/${jwt}`,
            query: {
                'force': force,
            },
        });
        return result.body;
    }
    /**
     * Get scans
     * Lists all your (runner) scans. <br> Please provide your runner jwt(that code we gave you during registration) for auth. <br> If you lost your jwt/personalized link please contact support.
     * @param jwt
     * @returns ResponseSelfServiceScan
     * @throws ApiError
     */
    static async runnerSelfServiceControllerGetScans(jwt) {
        const result = await (0, request_1.request)({
            method: 'GET',
            path: `/api/runners/me/${jwt}/scans`,
        });
        return result.body;
    }
    /**
     * Get station me
     * Lists basic information about the station whose token got provided. <br> This includes it's associated track.
     * @returns ResponseScanStation
     * @throws ApiError
     */
    static async runnerSelfServiceControllerGetStationMe() {
        const result = await (0, request_1.request)({
            method: 'GET',
            path: `/api/stations/me`,
        });
        return result.body;
    }
    /**
     * Request new token
     * Use this endpoint to reuqest a new selfservice magic-login-link to be sent to your mail address (rate limited to one mail every 15mins).
     * @param mail
     * @param locale
     * @returns any Successful response
     * @throws ApiError
     */
    static async runnerSelfServiceControllerRequestNewToken(mail, locale) {
        const result = await (0, request_1.request)({
            method: 'POST',
            path: `/api/runners/login`,
            query: {
                'mail': mail,
                'locale': locale,
            },
        });
        return result.body;
    }
    /**
     * Register runner
     * Create a new selfservice runner in the citizen org. <br> This endpoint shoud be used to allow "everyday citizen" to register themselves. <br> You have to provide a mail address, b/c the future we'll implement email verification.
     * @param locale
     * @param requestBody CreateSelfServiceCitizenRunner
     * @returns ResponseSelfServiceRunner
     * @throws ApiError
     */
    static async runnerSelfServiceControllerRegisterRunner(locale, requestBody) {
        const result = await (0, request_1.request)({
            method: 'POST',
            path: `/api/runners/register`,
            query: {
                'locale': locale,
            },
            body: requestBody,
        });
        return result.body;
    }
    /**
     * Register organization runner
     * Create a new selfservice runner in a provided org. <br> The orgs get provided and authorized via api tokens that can be optained via the /organizations endpoint.
     * @param token
     * @param locale
     * @param requestBody CreateSelfServiceRunner
     * @returns ResponseSelfServiceRunner
     * @throws ApiError
     */
    static async runnerSelfServiceControllerRegisterOrganizationRunner(token, locale, requestBody) {
        const result = await (0, request_1.request)({
            method: 'POST',
            path: `/api/runners/register/${token}`,
            query: {
                'locale': locale,
            },
            body: requestBody,
        });
        return result.body;
    }
    /**
     * Get selfservice org
     * Get the basic info and teams for a org.
     * @param token
     * @returns ResponseSelfServiceOrganisation
     * @throws ApiError
     */
    static async runnerSelfServiceControllerGetSelfserviceOrg(token) {
        const result = await (0, request_1.request)({
            method: 'GET',
            path: `/api/organizations/selfservice/${token}`,
        });
        return result.body;
    }
}
exports.RunnerSelfService = RunnerSelfService;
